==> apache-camel-3.4.6-src.zip: apache-camel-3.4.6/components/camel-etcd/src/main/java/org/apache/camel/component/etcd/EtcdStatsEndpoint.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.etcd;

import mousio.etcd4j.EtcdClient;
import org.apache.camel.Consumer;
import org.apache.camel.Processor;
import org.apache.camel.Producer;
import org.apache.camel.spi.UriEndpoint;

/**
 * Access etcd cluster statistcs.
 */
@UriEndpoint(firstVersion = "2.18.0", scheme = "etcd-stats", title = "Etcd Stats",
        syntax = "etcd-stats:path", label = "clustering,database")
public class EtcdStatsEndpoint extends AbstractEtcdPollingEndpoint {

    public EtcdStatsEndpoint(
            String uri, AbstractEtcdComponent component, EtcdConfiguration configuration, String path) {
        super(uri, component, configuration, path);
    }

    @Override
    public Producer createProducer() throws Exception {
        return new EtcdStatsProducer(this, getConfiguration(), getPath());
    }

    @Override
    public Consumer createConsumer(Processor processor) throws Exception {
        EtcdStatsConsumer consumer = new EtcdStatsConsumer(this, processor);
        configureConsumer(consumer);
        return consumer;
    }

    Object getStats(EtcdClient client) {
        switch (getPath()) {
            case EtcdConstants.ETCD_LEADER_STATS_PATH:
                return client.getLeaderStats();
            case EtcdConstants.ETCD_SELF_STATS_PATH:
                return client.getSelfStats();
            case EtcdConstants.ETCD_STORE_STATS_PATH:
                return client.getStoreStats();
            default:
                throw new IllegalStateException("No stats for " + getPath());
        }
    }
}

==> apache-camel-3.16.0-src.zip: apache-camel-3.16.0/components/camel-etcd/src/main/java/org/apache/camel/component/etcd/EtcdStatsEndpoint.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.etcd;

import mousio.etcd4j.EtcdClient;
import org.apache.camel.Consumer;
import org.apache.camel.Processor;
import org.apache.camel.Producer;
import org.apache.camel.spi.UriEndpoint;

import static org.apache.camel.component.etcd.EtcdConstants.SCHEME_STATS;

/**
 * Access etcd cluster statistcs.
 */
@UriEndpoint(firstVersion = "2.18.0", scheme = SCHEME_STATS, title = "Etcd Stats",
             syntax = "etcd-stats:path", label = "clustering,database", headersClass = EtcdConstants.class)
public class EtcdStatsEndpoint extends AbstractEtcdPollingEndpoint {

    public EtcdStatsEndpoint(
                             String uri, AbstractEtcdComponent component, EtcdConfiguration configuration, String path) {
        super(uri, component, configuration, path);
    }

    @Override
    public Producer createProducer() throws Exception {
        return new EtcdStatsProducer(this, getConfiguration(), getPath());
    }

    @Override
    public Consumer createConsumer(Processor processor) throws Exception {
        EtcdStatsConsumer consumer = new EtcdStatsConsumer(this, processor);
        configureConsumer(consumer);
        return consumer;
    }

    Object getStats(EtcdClient client) {
        switch (getPath()) {
            case EtcdConstants.ETCD_LEADER_STATS_PATH:
                return client.getLeaderStats();
            case EtcdConstants.ETCD_SELF_STATS_PATH:
                return client.getSelfStats();
            case EtcdConstants.ETCD_STORE_STATS_PATH:
                return client.getStoreStats();
            default:
                throw new IllegalStateException("No stats for " + getPath());
        }
    }
}
